@@ -1,35 +1,45 @@
 from __future__ import annotations
 
+import typing
 from functools import wraps
-from pathlib import Path
-from typing import Any, AnyStr, Callable, Hashable, NoReturn, Optional, TYPE_CHECKING, Type
+from typing import (
+    Any, Callable, Optional,
+    TYPE_CHECKING, Type, Union
+)
 
 from ConfigFramework.loaders.composite_loader import CompositeLoader
 
 if TYPE_CHECKING:
+    from ConfigFramework.custom_types import key_type
     from .abc_loader import AbstractConfigLoader
-    from ConfigFramework.dump_caster import DumpCaster
+
+Var = typing.TypeVar('Var')
 
 
-class AbstractConfigVar:
+class AbstractConfigVar(typing.Generic[Var]):
+    key: key_type
+    is_constant: bool
+    loader: AbstractConfigLoader
+
     """
     Abstract config variable with descriptors interface which is a base type for any of your variables classes.
-
     """
     def __init__(
-        self, key: [Hashable, AnyStr, Path], loader: AbstractConfigLoader, *,
-        typehint: Optional[Type] = Any,
-        caster: Optional[Callable] = None, dump_caster: Optional[Callable, DumpCaster] = None,
-        validator: Optional[Callable] = None, default: Optional[Any] = None, constant: bool = False
+        self, key: key_type, loader: AbstractConfigLoader, *,
+        typehint: Optional[Union[Type, Any]] = Any,  # noqa: backwards compatibility
+        caster: Optional[Callable[[Any], Var]] = None,
+        dump_caster: Optional[Callable[[AbstractConfigVar], Any]] = None,
+        validator: Optional[Callable[[Var], bool]] = None,
+        default: Optional[Any] = None,
+        constant: bool = False
     ):
         """
         Initializes variable for specified first_loader and key.
 
-        :param key: Any hashable, string or Path instance.
-            Example of how to get such vars: `config_root/database/database_ip`.
-            Warning: you must not start config paths with / or \\ since it may cause unwanted errors
+        :param key: Any hashable, string or Path instance. Example
+            of how to get such vars: `config_root/database/database_ip`. Warning:
+            you must not start config paths with / or \\ since it may cause unwanted errors
             because `pathlib.Path` is used to transform these to keys sequence.
-
         :param loader: A first_loader that will be looked up to get vars config_var or to update values.
         :param typehint: Typehint for __value field, that by default being returned.
         :param caster: Callable that should return variable casted to specific type (in case you need custom types).
@@ -42,6 +52,12 @@ class AbstractConfigVar:
         .. versionadded:: 2.1.0
            pathlib.Path support as variable key.
 
+        .. versionadded:: 2.2.0
+            AbstractConfigVar can be used as a type hint.
+
+        .. deprecated:: 2.2.0
+            typehint parameter is deprecated and will be deleted in 2.5.0. To use type hints use
+            AbstractConfigVar[desired_type] instead.
         """
         self.key = key
         self.is_constant = constant
@@ -57,31 +73,31 @@ class AbstractConfigVar:
                 setattr(self, redefine_func_name, func)
 
         if default is not None:
-            self.__value: typehint = self.caster(loader.get(key, default))
+            self.__value = self.caster(loader.get(key, default))
             default = self.caster(default)
 
         else:
-            self.__value: typehint = self.caster(loader[key])
+            self.__value = self.caster(loader[key])
 
         # Validation of config_var and defaults
         bool_casted_validator: Callable = self._validate_to_bool(self.validate)
 
         if not bool_casted_validator(self.__value):
             if (default is not None) and bool_casted_validator(default):
-                self.__value: typehint = default
+                self.__value = default
 
             elif self._validate_value_in_defaults(self.validate, self.caster, loader, key):
                 key = loader.key_to_path_cast(key)
                 var_key = loader.key_to_path_cast(key)
 
-                self.value: typehint = loader.get_to_variable_root(key, lookup_at=loader.defaults)[var_key]
+                self.value = loader.get_to_variable_root(key, lookup_at=loader.defaults)[var_key]
 
             else:
                 raise ValueError(f"Invalid config_var for {self} in {self.loader} and default values not found")
 
         self.__post_init = True
 
-    def caster(self, value: Any) -> Any:
+    def caster(self, value: Any) -> Var:
         """
         Callable that should return variable casted to specific type (in case you need custom types).
 
@@ -103,7 +119,7 @@ class AbstractConfigVar:
         """
         return config_var.__value
 
-    def validate(self, value: Any) -> bool:  # noqa
+    def validate(self, value: Var) -> bool:  # noqa
         """
         Callable that validates config_var or defaults in case the original config_var is invalid.
 
@@ -118,12 +134,9 @@ class AbstractConfigVar:
 
         :return: loader class.
         """
-        if not isinstance(self.loader, CompositeLoader):
-            return type(self.loader)
-
-        else:
-            self.loader: CompositeLoader
-            for loader in self.loader.loaders:
+        if isinstance(self.loader, CompositeLoader):
+            composite_loader: CompositeLoader = self.loader
+            for loader in composite_loader.loaders:
                 try:
                     loader[self.key]
 
@@ -133,8 +146,13 @@ class AbstractConfigVar:
                 else:
                     return type(loader)
 
+            raise KeyError(f"No key {self.key} found in any loaders of {self.loader}")
+
+        else:
+            return type(self.loader)
+
     @staticmethod
-    def _validate_to_bool(func):
+    def _validate_to_bool(func) -> Callable[[Var], bool]:
         """
         Wrapper that returns a bool config_var representing if check failed or raised ValueError.
 
@@ -153,15 +171,22 @@ class AbstractConfigVar:
         return execute
 
     @staticmethod
-    def _validate_value_in_defaults(validator: Callable, caster: Callable, loader: AbstractConfigLoader, key) -> bool:
+    def _validate_value_in_defaults(
+        validator: Callable,
+        caster: Callable,
+        loader: AbstractConfigLoader,
+        key: key_type
+    ) -> bool:
         if not hasattr(loader, 'defaults'):
             return False
 
-        bool_casted_validator: Callable = AbstractConfigVar._validate_to_bool(validator)
+        bool_casted_validator: Callable[[Var], bool] = AbstractConfigVar._validate_to_bool(validator)
         *keys, variable_key = loader.key_to_path_cast(key)
 
         try:
-            variable_root = loader.get_to_variable_root(keys, lookup_at=loader.defaults)
+            variable_root = loader.get_to_variable_root(
+                tuple(keys), lookup_at=loader.defaults
+            )
             variable = variable_root[variable_key]
 
         except KeyError:
@@ -170,7 +195,7 @@ class AbstractConfigVar:
         return bool_casted_validator(caster(variable))
 
     @property
-    def value(self) -> Any:
+    def value(self) -> Var:
         """
         Gives access to casted value.
 
@@ -179,7 +204,7 @@ class AbstractConfigVar:
         return self.__value
 
     @value.setter
-    def value(self, value: Any) -> NoReturn:
+    def value(self, value: Any) -> None:
         """
         Sets a new value to config variable and updates its value in loader with casting it to needed type.
 
@@ -202,4 +227,4 @@ class AbstractConfigVar:
         return f"{self.key} in {self.loader} = {self.__value}"
 
 
-__all__ = ["AbstractConfigVar"]
+__all__ = ["AbstractConfigVar", "Var"]
